@@ -33,6 +33,10 @@ debug=0
 test=0
 logfilename=""
 logfile=""
+lastlogfile=""
+Note=""
+Header=""
+#ChangedNote=0
 StartTime=0
 StartTimeSec=0
 StopTime=0
