@@ -274,12 +274,22 @@ class frmStartWindow(QtGui.QWidget):
     def ShowLogWindow(self):
         global LogWindowGraph
         
-        tmp= QFileDialog.getOpenFileName(None,"Open SleepCycle Log File", data.logfolder, "Log Files (*.csv)");
-        tmp2=tmp.split("/")
-        l=len(tmp2)    
-        x=tmp2[l-1]
-        if(x==""): return #only continue if valid log file selected
-        data.logfilename=x
+        if os.path.exists(data.logfolder+data.lastlogfile):
+            data.logfilename=data.lastlogfile
+        else:
+            LoadFileList()
+            l=len(data.arrLogFiles)
+            if(l>0):
+                data.logfilename=data.arrLogFiles[l-1] #open last (youngest) log file
+            else: #no logfiles in logfolder, show "open file" dialog
+                tmp= QFileDialog.getOpenFileName(None,"Open SleepCycle Log File", data.logfolder, "Log Files (*.csv)");
+                tmp2=tmp.split("/")
+                l=len(tmp2)    
+                x=tmp2[l-1]
+                if(x==""): return #only continue if valid log file selected
+                data.logfilename=x
+        
+        print data.logfilename
         
         LogWindowGraph = LogWindowCanvas()
         LogWindow.ShowLogFile()
@@ -438,7 +448,12 @@ class frmCollectingWindow(QtGui.QWidget):
         if reply == QtGui.QMessageBox.No:
             print "Delete logfile: "+data.logfilename
             os.remove(data.logfolder+data.logfilename)
+        else:
+            data.lastlogfile=data.logfilename
+#            print "lastlogfile:",  data.lastlogfile
+            config.set('main', 'lastlogfile', str(data.lastlogfile))   
             
+        #in case measurement is still running (user did not click on "stop")
         if(data.run==1): StopMeasurement()
         StartWindow.show()
 #        NoteWindow.show()
@@ -469,11 +484,14 @@ class frmLogWindow(QtGui.QWidget):
         QtCore.QObject.connect(self.ui.bNext, QtCore.SIGNAL("clicked()"), self.NextLogFile)
         QtCore.QObject.connect(self.ui.bLast, QtCore.SIGNAL("clicked()"), self.LastLogFile)
         QtCore.QObject.connect(self.ui.bDelete, QtCore.SIGNAL("clicked()"), self.DeleteLogFile)
+        QtCore.QObject.connect(self.ui.bOpen, QtCore.SIGNAL("clicked()"), self.Open)
+        QtCore.QObject.connect(self.ui.bEditNote, QtCore.SIGNAL("clicked()"), self.EditNote)
         
         if(data.app_path!="./"): #only needed if not started in app path
             self.ui.bLast.setIcon(QIcon(data.app_path+"go-previous.png"))
             self.ui.bNext.setIcon(QIcon(data.app_path+"go-next.png"))
             self.ui.bDelete.setIcon(QIcon(data.app_path+"edittrash.png"))
+            self.ui.bOpen.setIcon(QIcon(data.app_path+"zoom.png"))
             self.ui.bZoomIn.setIcon(QIcon(data.app_path+"zoom-in.png"))
             self.ui.bZoomOut.setIcon(QIcon(data.app_path+"zoom-out.png"))
             self.ui.bRaiseTrigger.setIcon(QIcon(data.app_path+"go-up.png"))
@@ -488,6 +506,7 @@ class frmLogWindow(QtGui.QWidget):
         self.ui.lblStoptime.setText(str(data.arrData[0][data.arrDataIndex-1]))
         self.ui.lblTrigger.setText(str(data.trigger))
         self.ui.lblYscale.setText(str(data.Yscale))
+        self.ui.lblNote.setText(str(data.Note))
 
         if(data.Xscale==0): self.ui.bZoomIn.setEnabled(False)
         else: self.ui.bZoomIn.setEnabled(True)
@@ -510,20 +529,15 @@ class frmLogWindow(QtGui.QWidget):
         LogWindowGraph = LogWindowCanvas()
         LogWindowGraph.show()
         self.UpdateScreen()
+#        data.ChangedNote=0
         
         
-    ###########################################################################
-    # Load next  logfile
-    ###########################################################################
     def NextLogFile(self):
         data.arrLogFileIndex=(data.arrLogFileIndex+1)  % len(data.arrLogFiles)
         data.logfilename=data.arrLogFiles[data.arrLogFileIndex]
         self.ShowLogFile()
 
 
-    ###########################################################################
-    # Load last logfile
-    ###########################################################################
     def LastLogFile(self):
         data.arrLogFileIndex=(data.arrLogFileIndex-1)  % len(data.arrLogFiles)
         data.logfilename=data.arrLogFiles[data.arrLogFileIndex]
@@ -569,18 +583,49 @@ class frmLogWindow(QtGui.QWidget):
         if reply == QtGui.QMessageBox.Yes:
             print "Delete logfile: "+data.logfilename
             os.remove(data.logfolder+data.logfilename)    
-            data.arrLogFileIndex=(data.arrLogFileIndex+1)  % len(data.arrLogFiles)
-            data.logfilename=data.arrLogFiles[data.arrLogFileIndex]
+
+            LoadFileList()
+            l=len(data.arrLogFiles)
+            if(l>0):
+                data.logfilename=data.arrLogFiles[l-1] #open last (youngest) log file
+            else: #no logfiles in logfolder, show "open file" dialog
+                x=self.ShowFileDialog()
+                if(x==""): 
+                    self.closeEvent("") #no file selected, close
+                    return
+                data.logfilename=x
             self.ShowLogFile()
 
 
 
+    def Open(self):
+        x=self.ShowFileDialog()
+        if(x==""):  return
+        data.logfilename=x
+        self.ShowLogFile()
+    
+    
+    
+    
+    def ShowFileDialog(self):
+        tmp= QFileDialog.getOpenFileName(None,"Open SleepCycle Log File", data.logfolder, "Log Files (*.csv)");
+        tmp2=tmp.split("/")
+        l=len(tmp2)    
+        x=tmp2[l-1]
+        return x
+
+
     def closeEvent(self, event):
         config.set('main', 'trigger', str(data.trigger))      
         LogWindow.close()
         StartWindow.show()
 
-
+    def EditNote(self):
+        r=QInputDialog.getText(None,  "Edit Note",  "Add a note to this record:",  QLineEdit.Normal,  data.Note)
+        if(r[1]==True): #OK pressed
+            data.Note=str(r[0])
+            self.ui.lblNote.setText(str(data.Note))
+            ChangeNoteInFile() #rewrite log file
 
 
 
