@@ -100,7 +100,7 @@ def LoadFileList():
 
 
 ###########################################################################
-#  Load old log file  to read and visualise it
+#  Load log file  to read and visualise it
 ###########################################################################
 def OpenLogFile():    
     Show_passed_time("OpenLogFile Start")
@@ -108,8 +108,29 @@ def OpenLogFile():
     data.arrDataIndex=0
     print "Open logfile",  data.logfilename
     try:
-        header=file.readline()
-        print "Header:",  header
+        data.Header=file.readline()
+        print "Header:",  data.Header
+        h=string.split(data.Header, ", ")
+        v=h[4]
+        SWversion=string.replace(v, "SW version:",  "")
+        try:
+            fl=float(SWversion)
+        except:
+            print "SW Version format not valid:",  SWversion
+            fl=0.0
+#        print v,  fl,  data.version
+        if(fl>1.1 and fl!=213.1321): #log files newer than SW version 1.1. and not Demo version have a new line with notes
+#            print "SW version > 1.1, contains Note"
+            data.Note=file.readline()
+            data.Note=string.replace(data.Note, "Note: ",  "")
+            data.Note=string.replace(data.Note, "\n",  "")
+        else:
+            data.Note=""
+            data.Header=string.replace(data.Header,  v,  "SW version: "+str(data.version))
+#            print "New header:",  data.Header
+        print "Note:",  data.Note
+            
+        
         for line in file:
             d=string.split(line,  ", ")
             data.arrData[0][data.arrDataIndex]=d[0] #time
@@ -128,6 +149,24 @@ def OpenLogFile():
     
     
     
+###########################################################################
+#  Load log file  to change Note (on line 2)
+###########################################################################
+def ChangeNoteInFile():    
+    file = open(data.logfolder+data.logfilename, 'w')
+    print "Open logfile",  data.logfilename
+    print "Change Note to\"",  data.Note,  "\" in file",  data.logfilename
+   
+   
+    file.write(data.Header)
+    file.write("Note: "+data.Note+"\n")
+    for i in range(0,  data.arrDataIndex):
+        d=str(data.arrData[0][i]) + ", " + str(data.arrData[1][i]) + ", " +  str(data.arrData[2][i])
+        file.write(d+"\n")
+    file.close()
+    print "Wrote",  i +1,  "lines into file"
+    
+    
     
     
 ###########################################################################
@@ -150,6 +189,7 @@ def LoadConfig():
         data.Xscale = config.getint('main', 'Xscale')
         data.Yscale = config.getint('main', 'Yscale')
         data.user = config.get('main', 'user')
+        data.lastlogfile = config.get('main', 'lastlogfile')
         print "Configuration loaded ("+data.ConfigFile+")"
 #    else:
     except: #use default config
@@ -167,6 +207,7 @@ def LoadConfig():
         config.set('main', 'Xscale', str(data.Xscale))     
         config.set('main', 'Yscale', str(data.Yscale))      
         config.set('main', 'user', str(data.user))      
+        config.set('main', 'lastlogfile', str(data.lastlogfile))      
 
     
     #print usefull data
